@@ -105,14 +105,14 @@ def find_programs(curdir: str):
 
     if sabnzbd.MACOS:
         if sabnzbd.MACOSARM64:
-            # M1 (ARM64) versions
-            sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "macos/par2/arm64/par2")
+            # ARM64 version of unrar
             sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "macos/unrar/arm64/unrar")
         else:
-            # Regular x64 versions
-            sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "macos/par2/par2")
+            # Regular x64 version
             sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "macos/unrar/unrar")
-        # The 7zip binary is universal2
+
+        # The par2 and 7zip binary are universal2
+        sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "macos/par2/par2")
         sabnzbd.newsunpack.SEVENZIP_COMMAND = check(curdir, "macos/7zip/7zz")
 
     if sabnzbd.WINDOWS:
